%define major		4
%define libname		%mklibname netcdf_c++ %{major}
%define develname	%mklibname netcdf_c++ -d

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf-cxx
Version:	4.2
Release:	%mkrel 17
Group:		Development/C++
License:	NetCDF
URL:		https://www.unidata.ucar.edu/software/netcdf/
Source0:	https://downloads.unidata.ucar.edu/netcdf-cxx/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	valgrind
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Shareable. One writer and multiple readers may simultaneously access the
     same netCDF file.

%package -n	%{libname}
Summary:	C++ libraries for netcdf
Group:		System/Libraries

%description -n	%{libname}
This package contains the netCDF C++ libraries.

%package -n	%{develname}
Summary:	Development files for netcdf-c++
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}netcdf-devel < 4.2.1.1

%description -n %{develname}
This package contains the netCDF-c++ header files, shared devel libs, and
man pages.

%prep
%setup -q

%build
# fix build on aarch64
autoreconf -vfi

%configure --enable-shared --disable-static
%make_build

%check
%__make check

%install
%make_install

rm -f %{buildroot}%{_libdir}/*.la

%files -n %{libname}
%{_libdir}/libnetcdf_c++.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/*.hh
%{_includedir}/*.h
%{_infodir}/*
%{_libdir}/libnetcdf_c++.so


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 4.2-17.mga10
+ Revision: 2213904
- Mageia 10 Mass Rebuild

* Sat Apr 02 2022 umeabot <umeabot> 4.2-16.mga9
+ Revision: 1840488
- Mageia 9 Mass Rebuild

* Sat Dec 11 2021 eatdirt <eatdirt> 4.2-15.mga9
+ Revision: 1761435
- Rebuild for new netcdf

* Mon Oct 26 2020 akien <akien> 4.2-14.mga8
+ Revision: 1639578
- Rebuild against libnetcdf18

* Thu Oct 01 2020 pterjan <pterjan> 4.2-13.mga8
+ Revision: 1631505
- Rebuild for new netcdf on arm

* Wed Mar 18 2020 daviddavid <daviddavid> 4.2-12.mga8
+ Revision: 1557594
- rebuild for new netcdf 4.7.3

* Thu Feb 13 2020 umeabot <umeabot> 4.2-11.mga8
+ Revision: 1515347
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.2-10.mga7
+ Revision: 1299703
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 eatdirt <eatdirt> 4.2-9.mga7
+ Revision: 1246658
- Rebuild for new netcdf

* Sun Jun 24 2018 wally <wally> 4.2-8.mga7
+ Revision: 1239399
- fix build on aarch64
+ kekepower <kekepower>
- Use new make macros

* Wed Feb 03 2016 umeabot <umeabot> 4.2-7.mga6
+ Revision: 933058
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.2-6.mga5
+ Revision: 745091
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2-5.mga5
+ Revision: 682846
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 4.2-4.mga5
+ Revision: 508285
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 12 2012 fwang <fwang> 4.2-2.mga3
+ Revision: 305124
- update file list
- imported package netcdf-cxx

